@@ -21,10 +21,15 @@ from scipy.special import logsumexp
 from scipy.stats import multivariate_normal
 from theano import function as theano_function
 
-from ..backends.ndarray import NDArray
-from ..model import Point, modelcontext
-from ..sampling import sample_prior_predictive
-from ..theanof import floatX, inputvars, join_nonshared_inputs, make_shared_replacements
+from pymc3.backends.ndarray import NDArray
+from pymc3.model import Point, modelcontext
+from pymc3.sampling import sample_prior_predictive
+from pymc3.theanof import (
+    floatX,
+    inputvars,
+    join_nonshared_inputs,
+    make_shared_replacements,
+)
 
 
 class SMC:
@@ -172,6 +177,8 @@ class SMC:
         self.log_marginal_likelihood += logsumexp(log_weights_un) - np.log(self.draws)
         self.beta = new_beta
         self.weights = np.exp(log_weights)
+        # We normalize again to correct for small numerical errors that might build up
+        self.weights /= self.weights.sum()
 
     def resample(self):
         """Resample particles based on importance weights."""
@@ -250,7 +257,7 @@ class SMC:
         varnames = [v.name for v in self.variables]
 
         with self.model:
-            strace = NDArray(self.model)
+            strace = NDArray(name=self.model.name)
             strace.setup(lenght_pos, self.chain)
         for i in range(lenght_pos):
             value = []
